import os
from importlib import reload
from importlib.machinery import SourceFileLoader
from inspect import getmembers, isfunction, isbuiltin
from typing import Callable


def find_local_function(module, path) -> Callable:
    method = None
    file_name, file_ext = os.path.splitext(path)

    # getmembers returns a list of tuples
    for name, item in getmembers(module):
        if (
            (
                file_name != "__init__"
                # we want to catch only local functions, not imported ones
                and isfunction(item)
                and not isbuiltin(item)
                and os.path.samefile(item.__code__.co_filename, path)
            )
            or (file_name.endswith("__init__") and isfunction(item))
        ):
            method = item

    return method


def handle(path: str):
    module_path = path

    if os.path.isdir(path):
        module_path = os.path.join(path, "__init__.py")

    if os.path.exists(module_path):
        module = SourceFileLoader("stardust.app", module_path).load_module()
    else:
        print("No such file or directory.")
        exit(1)

    return find_local_function(module, module_path)



import os
from pathlib import Path

from setuptools import find_packages, setup

require = ["starlette==0.18.0", "uvicorn==0.17.5"]

THIS_DIR = Path(__file__).parent.resolve()
with open(os.path.join(THIS_DIR, "README.md"), encoding="utf-8") as f:
    long_description = "\n" + f.read()

setup(
    name="stardust",
    version="0.0.4",
    description="Stardust is micro web framework inspired by serverless and lambda deployments.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lukefx/stardust.git",
    author="Luca Simone",
    author_email="info@lucasimone.info",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    py_modules=["stardust"],
    scripts=["bin/stardust"],
    packages=find_packages(
        exclude=["examples", "*.tests", "*.tests.*", "tests.*", "tests", "local"]
    ),
    include_package_data=True,
    install_requires=require,
)
